@@ -5,6 +5,9 @@ from tests.dialects.test_dialect import Validator
 class TestStarrocks(Validator):
     dialect = "starrocks"
 
+    def test_starrocks(self):
+        self.validate_identity("ALTER TABLE a SWAP WITH b")
+
     def test_ddl(self):
         ddl_sqls = [
             "DISTRIBUTED BY HASH (col1) BUCKETS 1",
@@ -36,6 +39,9 @@ class TestStarrocks(Validator):
         self.validate_identity(
             """SELECT CAST(PARSE_JSON(fieldvalue) -> '00000000-0000-0000-0000-00000000' AS VARCHAR) AS `code` FROM (SELECT '{"00000000-0000-0000-0000-00000000":"code01"}') AS t(fieldvalue)"""
         )
+        self.validate_identity(
+            "SELECT text FROM example_table", write_sql="SELECT `text` FROM example_table"
+        )
 
     def test_time(self):
         self.validate_identity("TIMESTAMP('2022-01-01')")
