@@ -883,3 +883,5 @@ GRANT SELECT, INSERT ON FUNCTION tbl TO user
 GRANT SELECT ON orders TO ROLE PUBLIC
 GRANT SELECT ON nation TO alice WITH GRANT OPTION
 GRANT DELETE ON SCHEMA finance TO bob
+SELECT attach
+SELECT detach
\ No newline at end of file
